@@ -171,7 +171,7 @@ set_rdhs_config <- function(email = NULL,
   assert_scalar_logical(verbose_setup)
   assert_scalar_logical(prompt)
   assert_scalar_numeric(timeout)
-
+  asked <- FALSE
 
   # This is in a hope to be compliant with the CRAN policy about not
   # writing to disk.  We need permission to write to a place that we
@@ -198,13 +198,15 @@ set_rdhs_config <- function(email = NULL,
   } else {
     if (!(options("rappdir_permission") == TRUE) && prompt){
       ask_user_permission()
+      asked <- TRUE
     }
     if (!(options("rappdir_permission") == TRUE)){
       config_path <- file.path(tempdir_check(), "rdhs/rdhs.json")
-      dir.create(file.path(tempdir_check(), "rdhs"), showWarnings = FALSE)
+      dir.create(file.path(tempdir_check(), "rdhs"),
+                 showWarnings = FALSE, recursive = TRUE)
     } else {
       config_path <- file.path(rappdirs_rdhs(), "rdhs.json")
-      dir.create(rappdirs_rdhs(), showWarnings = FALSE)
+      dir.create(rappdirs_rdhs(), showWarnings = FALSE, recursive = TRUE)
     }
   }
 
@@ -215,15 +217,15 @@ set_rdhs_config <- function(email = NULL,
 
   # if we have no cache_path then set this to temp
   if (is.null(cache_path)){
-    if (!(options("rappdir_permission") == TRUE) && prompt){
+    if (!(options("rappdir_permission") == TRUE) && prompt && !asked){
       ask_user_permission()
     }
     if (!(options("rappdir_permission") == TRUE)){
       cache_path <- file.path(tempdir_check(), "rdhs")
-      dir.create(cache_path, showWarnings = FALSE)
+      dir.create(cache_path, showWarnings = FALSE, recursive = TRUE)
     } else {
       cache_path <- rappdirs_rdhs()
-      dir.create(cache_path, showWarnings = FALSE)
+      dir.create(cache_path, showWarnings = FALSE, recursive = TRUE)
     }
   }
 
@@ -270,8 +272,10 @@ write_rdhs_config_file <- function(dat, path) {
     "Writing your configuration to:\n   -> ", path, "\n"
   )
 
-  # and add this to gitignore if there
-  add_line(".gitignore", path)
+  # and add this to gitignore if it is a non global config file
+  if (!dat$global) {
+    add_line(".gitignore", path)
+  }
 
   writeLines(str, path)
   invisible(read_rdhs_config_file(path))
