@@ -27,7 +27,7 @@ test_that("available surveys and download work", {
   )
 
   # check handle for dataset you don't have permission for
-  downloads <- cli$get_datasets("CDGC61FL.ZIP")
+  expect_message(downloads <- cli$get_datasets("CDGC61FL.ZIP"), "not available")
 
   # check dta foreign only
   downloads <- cli$get_datasets(
@@ -134,7 +134,7 @@ test_that("ETAR71FL.ZIP test", {
 
   dat <- cli$get_datasets("ETAR71FL.ZIP")
   r <- readRDS(dat[[1]])
-  expect_identical(class(r), c("data.frame", "dhs_dataset"))
+  expect_identical(class(r), "data.frame")
 })
 
 test_that("ugir41fl.zip test", {
@@ -156,7 +156,10 @@ test_that("zip file ending test", {
   extension <- strsplit(dat$ETAR61FL, ".", fixed = TRUE) %>%
     lapply(function(x) x[length(x)]) %>%
     unlist()
-  expect_identical(toupper(extension), "ZIP")
+  expect_true(
+    (toupper(extension) == "ZIP") ||
+      (toupper(extension) == "DATASET IS NOT AVAILABLE WITH YOUR DHS LOGIN CREDENTIALS")
+  )
 })
 
 test_that("Hierarchal and sas7bdat dataset test", {
